@@ -54,36 +54,11 @@ AssociationRulesAlgorithm <- R6::R6Class("AssociationRulesAlgorithm",
     },
 
     run = function(folderPath, expUniqueName, javaOptions){
+
+      super$run(folderPath, expUniqueName, javaOptions)
+
       #Use tryCatch() to remove experiment folders even it there are errors
       tryCatch({
-        #Experiment folder
-        #expPath <- gsub("//", "/", system.file("exp", "", package="RKEEL"))
-
-        if(missing(folderPath)){
-          expPath <- gsub("\\\\", "/", tempdir())
-        }
-        else{
-          expPath <- folderPath
-        }
-
-        if(substr(expPath, nchar(expPath), nchar(expPath)) != "/"){
-          expPath <- paste0(expPath, "/")
-        }
-
-        if(missing(expUniqueName)){
-          private$mainPath <- paste0(expPath, "experiment_", gsub(" ", "_", gsub(":", "-", toString(Sys.time()))), sample(1:10000, 1))
-        }
-        else{
-          private$mainPath <- paste0(expPath, expUniqueName)
-        }
-
-        if(dir.exists(private$mainPath)){
-          stop(paste0("The current experiment folder ",  private$mainPath, " already exists. Please select an unique experiment folder name.", sep="\n"))
-        }
-
-        private$generateExperimentDir(private$mainPath)
-
-        #Copy dataset folder
         #Create dataset folder
         dir.create(paste0(private$mainPath, "/datasets/", private$dataName))
         #Write dataset files
@@ -138,10 +113,10 @@ AssociationRulesAlgorithm <- R6::R6Class("AssociationRulesAlgorithm",
 
         setwd(paste0(private$mainPath, "/scripts/"))
         if(grepl("windows", tolower(Sys.info()[1]))) {
-          system(paste0(private$javaPath, "java ", javaOptions, " -jar RunKeel.jar"), show.output.on.console = FALSE)
+          system(paste0(private$javaPath, "java ", private$javaOpt, " -jar RunKeel.jar"), show.output.on.console = FALSE)
         }
         else {
-          system(paste0(private$javaPath, "java ", javaOptions, " -jar RunKeel.jar"), ignore.stdout = TRUE)
+          system(paste0(private$javaPath, "java ", private$javaOpt, " -jar RunKeel.jar"), ignore.stdout = TRUE)
         }
         setwd(wdPath)
 
